@@ -224,6 +224,15 @@ public final class POP3Properties extends AbstractProtocolProperties implements
         cipherSuites = null;
     }
 
+    /**
+     * Gets the spam handler name.
+     *
+     * @return The spam handler name
+     */
+    public String getSpamHandlerName() {
+        return spamHandlerName;
+    }
+
     @Override
     public String getPOP3AuthEnc() {
         return pop3AuthEnc;
@@ -254,65 +263,16 @@ public final class POP3Properties extends AbstractProtocolProperties implements
         return pop3BlockSize;
     }
 
-    /**
-     * Gets the spam handler name.
-     *
-     * @return The spam handler name
-     */
-    public String getSpamHandlerName() {
-        return spamHandlerName;
-    }
-
-    @Override
-    public int getAttachDisplaySize() {
-        return mailProperties.getAttachDisplaySize();
-    }
-
-    @Override
-    public char getDefaultSeparator() {
-        return mailProperties.getDefaultSeparator();
-    }
-
-    @Override
-    public int getMailAccessCacheIdleSeconds() {
-        return mailProperties.getMailAccessCacheIdleSeconds();
-    }
-
-    @Override
-    public int getMailAccessCacheShrinkerSeconds() {
-        return mailProperties.getMailAccessCacheShrinkerSeconds();
-    }
-
     @Override
     public int getMailFetchLimit() {
         return mailProperties.getMailFetchLimit();
     }
 
-    @Override
-    public int getWatcherFrequency() {
-        return mailProperties.getWatcherFrequency();
-    }
-
-    @Override
-    public int getWatcherTime() {
-        return mailProperties.getWatcherTime();
-    }
-
     @Override
     public boolean isAllowNestedDefaultFolderOnAltNamespace() {
         return mailProperties.isAllowNestedDefaultFolderOnAltNamespace();
     }
 
-    @Override
-    public boolean isEnforceSecureConnection() {
-        return mailProperties.isEnforceSecureConnection();
-    }
-
-    @Override
-    public void setEnforceSecureConnection(boolean enforceSecureConnection) {
-        mailProperties.setEnforceSecureConnection(enforceSecureConnection);
-    }
-
     @Override
     public boolean isIgnoreSubscription() {
         return mailProperties.isIgnoreSubscription();
@@ -328,16 +288,6 @@ public final class POP3Properties extends AbstractProtocolProperties implements
         return mailProperties.isUserFlagsEnabled();
     }
 
-    @Override
-    public boolean isWatcherEnabled() {
-        return mailProperties.isWatcherEnabled();
-    }
-
-    @Override
-    public boolean isWatcherShallClose() {
-        return mailProperties.isWatcherShallClose();
-    }
-
     @Override
     public String getSSLProtocols() {
         return sslProtocols;
